import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:practica1_flutter/src/models/category_model.dart';
import '../http_api/category_api.dart';

class CategoryForm extends StatelessWidget {
  final GlobalKey<FormState> _formKey = GlobalKey<FormState>();
  final TextEditingController _claveController = TextEditingController();
  final TextEditingController _fechaCreadoController = TextEditingController();
  final TextEditingController _nombreController = TextEditingController();

  int _getFechaCreadoEnMilisegundos(String fecha) {
    try {
      DateTime fechaCreado = DateTime.parse(fecha);
      return fechaCreado.millisecondsSinceEpoch;
    } catch (e) {
      return 0;
    }
  }

  // Función para guardar la categoría
  void _saveCategory(BuildContext context) async {

    if (_formKey.currentState!.validate()) {
      final clave = _claveController.text.trim();
      final nombre = _nombreController.text.trim();
      final fechaCreadoStr = _fechaCreadoController.text.trim();

      if (clave.isEmpty || nombre.isEmpty || fechaCreadoStr.isEmpty) {
        ScaffoldMessenger.of(context).showSnackBar(
          SnackBar(content: Text('Todos los campos deben estar completos')),
        );
        return;
      }

      final fechaCreado = _getFechaCreadoEnMilisegundos(fechaCreadoStr);

      CategoryModel category = CategoryModel(
        id: 0,
        version: 0,
        key: clave,
        name: nombre,
        createdDate: fechaCreado,
        active: true,
      );

      final categoryService = CategoryService();
      final response = await categoryService.addCategory(category);

      print('Response Status Code: ${response['statusCode']}');
      print('Response Body: ${response['body']}');

      if (response['statusCode'] == 200) {
        ScaffoldMessenger.of(context).showSnackBar(
          SnackBar(content: Text('Categoría guardada exitosamente')),
        );
        Navigator.pushReplacementNamed(context, 'homeSeller');
      } else {
        final responseBody = json.decode(response['body']);
        final errorMessage = responseBody['error'] ?? 'Error desconocido';
        ScaffoldMessenger.of(context).showSnackBar(
          SnackBar(content: Text('Error al guardar categoría: $errorMessage')),
        );
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('Agregar Categoría'),
      ),
      body: Padding(
        padding: const EdgeInsets.all(16.0),
        child: Form(
          key: _formKey,
          child: Column(
            children: [
              // -----   AGREGAR CLAVE  ----
              TextFormField(
                controller: _claveController,
                decoration: InputDecoration(labelText: 'Clave',
                    border: OutlineInputBorder()),
                validator: (value) {
                  if (value == null || value.isEmpty) {
                    return 'Por favor ingrese la clave';
                  }
                  return null;
                },
              ),
              SizedBox(height: 20),

              // -----   AGREGAR FECHA ----
              TextFormField(
                controller: _fechaCreadoController,
                decoration: InputDecoration(labelText: 'Fecha FORMATO(YYYY-MM-DD)',
                    border: OutlineInputBorder()),
                validator: (value) {
                  if (value == null || value.isEmpty) {
                    return 'Por favor ingrese la fecha en formato YYYY-MM-DD';
                  }
                  try {
                    DateTime.parse(value);
                  } catch (e) {
                    return 'Por favor ingrese una fecha válida';
                  }
                  return null;
                },
              ),
              SizedBox(height: 20),
              // -----   AGREGAR NOMBRE DEL ARTICULO   ----
              TextFormField(
                controller: _nombreController,
                decoration: InputDecoration(labelText: 'Nombre',
                    border: OutlineInputBorder()),
                validator: (value) {
                  if (value == null || value.isEmpty) {
                    return 'Por favor ingrese el nombre';
                  }
                  return null;
                },
              ),
              SizedBox(height: 20),
              ElevatedButton(
                onPressed: () => _saveCategory(context),
                child: Text('GUARDAR'),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
